{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "biocontainers/bedtools:2.25.0",
                    "class": "DockerRequirement"
                },
                {
                    "coresMin": 1,
                    "ramMin": 15000,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": [
                "bedtools",
                "bedtobam"
            ],
            "stdout": "$(inputs.bed.nameroot + \".bam\")",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-i"
                    },
                    "id": "#bedtools_bedtobam.cwl/bed"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-g"
                    },
                    "id": "#bedtools_bedtobam.cwl/genome_info"
                }
            ],
            "id": "#bedtools_bedtobam.cwl",
            "outputs": [
                {
                    "type": "File",
                    "id": "#bedtools_bedtobam.cwl/bam",
                    "outputBinding": {
                        "glob": "$(inputs.bed.nameroot + \".bam\")"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "kerstenbreuer/deeptools:3.1.1",
                    "class": "DockerRequirement"
                },
                {
                    "coresMin": 1,
                    "ramMin": 20000,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": [
                "bamCoverage"
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.bam.nameroot + \".bigwig\")",
                    "prefix": "--outFileName",
                    "position": 10
                },
                {
                    "valueFrom": "bigwig",
                    "prefix": "--outFileFormat",
                    "position": 10
                },
                {
                    "valueFrom": "${ \n  if( inputs.spike_in_count == null ){\n    return \"RPGC\"\n  }\n  else{\n    return null \n  }\n}\n",
                    "prefix": "--normalizeUsing",
                    "position": 10
                }
            ],
            "inputs": [
                {
                    "doc": "bam file as input; needs bai index file in the same directory",
                    "type": "File",
                    "secondaryFiles": ".bai",
                    "inputBinding": {
                        "position": 100,
                        "prefix": "--bam"
                    },
                    "id": "#deeptools_bamCoverage.cwl/bam"
                },
                {
                    "type": "int",
                    "default": 10,
                    "inputBinding": {
                        "prefix": "--binSize",
                        "position": 10
                    },
                    "id": "#deeptools_bamCoverage.cwl/bin_size"
                },
                {
                    "doc": "the effectively mappable genome size, \nsee: https://deeptools.readthedocs.io/en/latest/content/feature/effectiveGenomeSize.html\n",
                    "type": "long",
                    "inputBinding": {
                        "position": 10,
                        "prefix": "--effectiveGenomeSize"
                    },
                    "id": "#deeptools_bamCoverage.cwl/effective_genome_size"
                },
                {
                    "doc": "List of space-delimited chromosome names that shall be ignored \nwhen calculating the scaling factor. \nSpecify as space-delimited string. \nDefault: \"chrX chrY chrM\"\n",
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "chrX chrY chrM",
                    "inputBinding": {
                        "prefix": "--ignoreForNormalization",
                        "position": 10
                    },
                    "id": "#deeptools_bamCoverage.cwl/ignoreForNormalization"
                },
                {
                    "doc": "number of reads aligned to the spike in genome, optional",
                    "type": [
                        "null",
                        "long"
                    ],
                    "inputBinding": {
                        "position": 10,
                        "prefix": "--scaleFactor",
                        "valueFrom": "${ \n  if( self == null ){\n    return null\n  }\n  else{\n    return (1.0 / parseFloat(self)) \n  }\n}\n"
                    },
                    "id": "#deeptools_bamCoverage.cwl/spike_in_count"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot + \".bigwig\")"
                    },
                    "id": "#deeptools_bamCoverage.cwl/bigwig"
                }
            ],
            "id": "#deeptools_bamCoverage.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "kerstenbreuer/samtools:1.7",
                    "class": "DockerRequirement"
                },
                {
                    "coresMin": 1,
                    "ramMin": 20000,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": [
                "bash",
                "-c"
            ],
            "arguments": [
                {
                    "valueFrom": "$(\"cp \" + inputs.bam_sorted.path + \" . && samtools index -b \" + inputs.bam_sorted.basename )"
                }
            ],
            "inputs": [
                {
                    "doc": "sorted bam input file",
                    "type": "File",
                    "id": "#samtools_index_hack.cwl/bam_sorted"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": ".bai",
                    "outputBinding": {
                        "glob": "$(inputs.bam_sorted.basename)"
                    },
                    "id": "#samtools_index_hack.cwl/bam_sorted_indexed"
                }
            ],
            "id": "#samtools_index_hack.cwl"
        },
        {
            "doc": "Sort a bam file by read names.",
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "kerstenbreuer/samtools:1.7",
                    "class": "DockerRequirement"
                },
                {
                    "coresMin": 4,
                    "ramMin": 15000,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": [
                "samtools",
                "sort"
            ],
            "arguments": [
                {
                    "valueFrom": "$(runtime.cores)",
                    "prefix": "-@"
                }
            ],
            "inputs": [
                {
                    "doc": "aligned reads to be checked in sam or bam format",
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#samtools_sort.cwl/bam_unsorted"
                }
            ],
            "stdout": "$(inputs.bam_unsorted.basename)",
            "outputs": [
                {
                    "type": "File",
                    "id": "#samtools_sort.cwl/bam_sorted",
                    "outputBinding": {
                        "glob": "$(inputs.bam_unsorted.basename)"
                    }
                }
            ],
            "id": "#samtools_sort.cwl"
        },
        {
            "class": "Workflow",
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/bed"
                },
                {
                    "type": "int",
                    "id": "#main/bin_size"
                },
                {
                    "type": "long",
                    "id": "#main/effective_genome_size"
                },
                {
                    "type": "File",
                    "id": "#main/genome_info"
                },
                {
                    "doc": "List of space-delimited chromosome names that shall be ignored \nwhen calculating the scaling factor. \nSpecify as space-delimited string. \nDefault: \"chrX chrY chrM\"\n",
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "chrX chrY chrM",
                    "id": "#main/ignoreForNormalization"
                }
            ],
            "steps": [
                {
                    "doc": "deeptools bamCoverage\n",
                    "run": "#deeptools_bamCoverage.cwl",
                    "in": [
                        {
                            "source": "#main/indexing_bam/bam_sorted_indexed",
                            "id": "#main/converting_bam_to_bigwig/bam"
                        },
                        {
                            "source": "#main/bin_size",
                            "id": "#main/converting_bam_to_bigwig/bin_size"
                        },
                        {
                            "source": "#main/effective_genome_size",
                            "id": "#main/converting_bam_to_bigwig/effective_genome_size"
                        },
                        {
                            "source": "#main/ignoreForNormalization",
                            "id": "#main/converting_bam_to_bigwig/ignoreForNormalization"
                        }
                    ],
                    "out": [
                        "#main/converting_bam_to_bigwig/bigwig"
                    ],
                    "id": "#main/converting_bam_to_bigwig"
                },
                {
                    "doc": "bedtools bedtobam - converts bed to bam;\nas most tools can handle bam as input but not always\nthe bed format(e.g. deeptools), moreover, bam is compressed;\ntherefore, it will be used as final output (instead of the bed file)\n",
                    "run": "#bedtools_bedtobam.cwl",
                    "in": [
                        {
                            "source": "#main/bed",
                            "id": "#main/converting_bed_to_bam/bed"
                        },
                        {
                            "source": "#main/genome_info",
                            "id": "#main/converting_bed_to_bam/genome_info"
                        }
                    ],
                    "out": [
                        "#main/converting_bed_to_bam/bam"
                    ],
                    "id": "#main/converting_bed_to_bam"
                },
                {
                    "doc": "samtools index - indexes sorted bam\n",
                    "run": "#samtools_index_hack.cwl",
                    "in": [
                        {
                            "source": "#main/sorting_bam/bam_sorted",
                            "id": "#main/indexing_bam/bam_sorted"
                        }
                    ],
                    "out": [
                        "#main/indexing_bam/bam_sorted_indexed"
                    ],
                    "id": "#main/indexing_bam"
                },
                {
                    "doc": "samtools sort - sorting of merged bam",
                    "run": "#samtools_sort.cwl",
                    "in": [
                        {
                            "source": "#main/converting_bed_to_bam/bam",
                            "id": "#main/sorting_bam/bam_unsorted"
                        }
                    ],
                    "out": [
                        "#main/sorting_bam/bam_sorted"
                    ],
                    "id": "#main/sorting_bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/indexing_bam/bam_sorted_indexed",
                    "id": "#main/bam"
                },
                {
                    "type": "File",
                    "outputSource": "#main/converting_bam_to_bigwig/bigwig",
                    "id": "#main/bigwig"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
